import greenfoot.*;  // (World, Actor, GreenfootImage, Greenfoot and MouseInfo)

import java.util.List;

/**
 * A Bomb. Explodes when hit
 * 
 * @author Michael Berry
 * @version (a version number or a date)
 */
public class Bomb extends Block
{
    /** Objects within this distance take a hit when the bomb explodes.*/
    public static final int BOMB_RADIUS = 40;
    /** The bomb's image. Static for performance reasons */
    public static final GreenfootImage image = new GreenfootImage("images/bomb.png");
    
    private Board board;
    
    /**
     * Create a new Bomb
     */  
    public Bomb()
    {
        super(1);
        setImage(image);
        //Default image is a bit big, need to make it smaller
        getImage().scale(30, 30);
    }
    
    /**
     * Called when the object is added to the world. Maintain a copy
     * of the board for reference.
     */
    public void addedToWorld(World world)
    {
        board = (Board)world;
    }
    
    /**
     * When hit, explode
     */
    public void hit()
    {
        board.addObject(new Explosion(), getX(), getY());
        List<Block> blocks = getObjectsInRange(BOMB_RADIUS, Block.class);
        for(Block block : blocks) {
            try {
                block.takeLife();
                block.hit();
            }
            catch(Exception ex) {}
        }
    }
}
